@@ -22,7 +22,7 @@
 #define HAVE_POP3
 
 /* Comment this out if you don't want to have MH support */
-//#define HAVE_MH
+#define HAVE_MH
 
 /* Comment this out if you don't want to have IMAP support */
 #define HAVE_IMAP
