@@ -251,7 +251,7 @@ int main(int argc, char **argv) {
                             draw_dockapp();
                             break;
                         case 2:
-                            if (event.xbutton.state == ControlMask)
+                            if ((event.xbutton.state & ControlMask) == ControlMask)
                                 my_system("wmmaiload-config -f ", config_file);
                             else
                                 if (command) my_system(command, NULL);
@@ -816,25 +816,21 @@ static Bool check_pop3(MailBox *box, time_t now) {
     Pop3 p3 = NULL;
 
     if ((now - box->time) > check_delay) {
+        int port;
         p3        = initPop3();
         box->time = time(0);
         switch(box->type) {
             case POP3:
-                if ((pop3Connect(p3, box->entry, 110)) == -1) {
-                    free_pop3(&p3);
-                    return False;
-                }
+                port = box->port != 0 ? box->port : 110;
                 break;
             case HOTMAIL:
-                if ((pop3Connect(p3, box->entry, 1100)) == -1) {
-                    free_pop3(&p3);
-                    return False;
-                }
+                port = box->port != 0 ? box->port : 1100;
                 break;
             default:
 		break;
         }
-        if ( ((pop3Login(p3, box->username, box->password)) == -1) ||
+        if ( ((pop3Connect(p3, box->entry, port)) == -1) ||
+             ((pop3Login(p3, box->username, box->password)) == -1) ||
              ((pop3CheckMail(p3)) == -1) ) {
             free_pop3(&p3);
             return False;
@@ -866,6 +862,7 @@ static Bool check_imap(MailBox *box, time_t now) {
 		if((imapCheckMail(imap, box->folder)) == -1)
 			return False;
 		imapQuit(imap);
+		free(imap);
 		box->new	= imapGetUnreadMess(imap);
 		box->total	= imapGetTotalMess(imap);
 		box->updated	= True;
@@ -956,6 +953,7 @@ static int my_system(char *cmd, char *param) {
         if (pid == 0) {
             char *argv[4];
             char fcmd[2048];
+            setsid();
             strncpy(fcmd, cmd, 2047);
             if (param) strncat(fcmd, param, 2045 - strlen(cmd));
             argv[0] = "sh";
@@ -979,7 +977,8 @@ static void mbox_add(MailBox **list, const char *value) {
     char     pass[25];
     char     btype[10];
     char     folder[100];
-    int count;
+    char    *pstr;
+    int count, port = 0;
 
     if (! value) return;
     bzero(box, 100);
@@ -989,6 +988,13 @@ static void mbox_add(MailBox **list, const char *value) {
     bzero(folder, 100);
     count = sscanf(value, "%s %s %s %s %s", btype, box, user, pass, folder);
 
+    pstr = strchr(box, ':');
+    if (pstr != NULL) {
+        *pstr = 0;
+        pstr++;
+        port = atoi(pstr);
+    }
+
     if (((getboxtype(btype) == MBOX) ||
          (getboxtype(btype) == MAILDIR) || 
          (getboxtype(btype) == MH)) &&
@@ -1022,6 +1028,7 @@ static void mbox_add(MailBox **list, const char *value) {
     lst->size     = 0;
     lst->new      = 0;
     lst->total    = 0;
+    lst->port     = port;
     lst->type     = getboxtype(btype);
     lst->username = user ? xstrdup(user) : NULL;
     lst->password = pass ? xstrdup(pass) : NULL;
